@@ -9,6 +9,17 @@ from .basic import compute, plot, render
 from .correlation import compute_correlation, plot_correlation, render_correlation
 from .missing import compute_missing, plot_missing, render_missing
 from .utils import is_notebook
+from .dtypes import (
+    DType,
+    Categorical,
+    Nominal,
+    Ordinal,
+    Numerical,
+    Continuous,
+    Discrete,
+    DateTime,
+    Text,
+)
 
 __all__ = [
     "plot_correlation",
@@ -20,7 +31,17 @@ __all__ = [
     "plot",
     "compute",
     "render",
+    "DType",
+    "Categorical",
+    "Nominal",
+    "Ordinal",
+    "Numerical",
+    "Continuous",
+    "Discrete",
+    "DateTime",
+    "Text" "",
 ]
 
+
 if is_notebook():
     output_notebook(hide_banner=True)
