@@ -4,7 +4,7 @@ from os import environ
 
 def test_data_connector() -> None:
     token = environ["DATAPREP_DATA_CONNECTOR_YELP_TOKEN"]
-    dc = Connector("yelp", auth_params={"access_token": token})
+    dc = Connector("yelp", _auth={"access_token": token})
     df = dc.query("businesses", term="ramen", location="vancouver")
 
     assert len(df) > 0
@@ -14,3 +14,11 @@ def test_data_connector() -> None:
     schema = dc.show_schema("businesses")
 
     assert len(schema) > 0
+
+    df = dc.query("businesses", _count=120, term="ramen", location="vancouver")
+
+    assert len(df) == 120
+
+    df = dc.query("businesses", _count=10000, term="ramen", location="vancouver")
+
+    assert len(df) < 1000
